<?php

class product_group extends CActiveRecord
{
	/**
	 * The followings are the available columns in table 'product_group':
	 * @var integer $product_group_id
	 * @var string $code
	 * @var string $name
	 * @var string $eu_standard
	 * @var string $size
	 * @var string $material
	 * @var string $colors
	 * @var string $notes
	 * @var string $deleted
	 * @var integer $sub_category_id
	 */

	/**
	 * Returns the static model of the specified AR class.
	 * @return CActiveRecord the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'product_group';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('code, name, eu_standard, size, material, colors, notes, sub_category_id', 'required'),
			array('sub_category_id', 'numerical', 'integerOnly'=>true),
			array('code', 'length', 'max'=>10),
			array('name', 'length', 'max'=>100),
			array('eu_standard', 'length', 'max'=>50),
			array('size', 'length', 'max'=>45),
			array('material, colors, notes', 'length', 'max'=>255),
			array('deleted', 'length', 'max'=>1),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'products' => array(self::HAS_MANY, 'product', 'code'),
			'sub_category' => array(self::BELONGS_TO, 'subCategory', 'sub_category_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'product_group_id' => 'Product Group',
			'code' => 'Code',
			'name' => 'Name',
			'eu_standard' => 'Eu Standard',
			'size' => 'Size',
			'material' => 'Material',
			'colors' => 'Colors',
			'notes' => 'Notes',
			'deleted' => 'Deleted',
			'sub_category_id' => 'Sub Category',
		);
	}
}